==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/wavpack/translations/wavpack_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="uk">
<defaultcodec></defaultcodec>
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="28"/>
        <source>WavPack Plugin</source>
        <translation>Модуль WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="30"/>
        <source>WavPack Files</source>
        <translation>Файли WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="89"/>
        <source>About WavPack Audio Plugin</source>
        <translation>Про аудіо-модуль WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="90"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Аудіо-модуль WavPack для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="92"/>
        <source>WavPack library version:</source>
        <translation>Версія бібліотеки WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="93"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>кБ/с</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>кБ</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Шлях до файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>Інформація WavPack</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>Тривалість:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>Дискретизація:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>Розмір файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>Каналів:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>Бітрейт:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>Стиснення:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>Версія:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>APE-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>Номер треку:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>Рік:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>Жінр:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>Коментар:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>Виконавець:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/wavpack/translations/wavpack_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>Модуль WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>Файли WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="129"/>
        <source>About WavPack Audio Plugin</source>
        <translation>Про аудіо-модуль WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="130"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Аудіо-модуль WavPack для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="131"/>
        <source>WavPack library version:</source>
        <translation>Версія бібліотеки WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="133"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>кБ/с</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>кБ</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Шлях до файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>Інформація WavPack</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>Тривалість:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="58"/>
        <location filename="../detailsdialog.ui" line="75"/>
        <location filename="../detailsdialog.ui" line="92"/>
        <location filename="../detailsdialog.ui" line="118"/>
        <location filename="../detailsdialog.ui" line="135"/>
        <location filename="../detailsdialog.ui" line="152"/>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>Дискретизація:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>Розмір файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>Каналів:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>Бітрейт:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>Стиснення:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>Версія:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>APE-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>Номер треку:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>Рік:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>Коментар:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>Виконавець:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
</TS>
